function [ P, L ] = LIP( x,f )
% function [ P, L ] = LIP( x,f )
% Lagrangeuv interpolacni polynom
% x - uzly
% f - funkcni hodnoty
% P - vysledny polynom
% L - matice koeficientu bazovych polynomu po radcich

n=length(x)-1;
if length(f)~=n+1
    error('Ruzna velikost vstupnich dat!');
end

L=[];
omega=poly(x);
for k=0:n
   Cit=deconv(omega,[1 -x(k+1)]);
   Jm=polyval(Cit,x(k+1));
   lk=Cit/Jm;
   L=[L;lk];
end

f=[f(:)]';
P=f*L;

end

